from distutils.core import setup

setup(
    name        = "tanbing1011",
    version     = "1.1.0",
    py_modules  = ['tanbing1011'],
    author      = "tanbing",
    author_email= "bing0ye@163.com",
    url         = "www.baidu.com",
    description = "Hello Python",
    )
